# Appchance Toolbelt for Python

Common models, dockerfiles, clients and project automation. Dig yourself to find your needs ;)

Use as submodule included at top-level directory of your project.
```bash
$ git submodule add git@bitbucket.org:appchance/pychance.git
```
